<?php
   /** Author:       Luke Ehresman
       Date:         January 2, 2000
       Theme Name:   'Default Theme'

       This is the default theme that comes standard with SquirrelMail.
       Most of the colors were taken from mail.yahoo.com's theme on their
       site.

       To create a new theme, just copy this file, and edit the colors.
       Be sure to rename the file and keep the original, just in case.

       NOTE:
       You might want to submit the theme you create to our Patches tracker
       on http://sourceforge.net/projects/squirrelmail
       for inclusion in further releases of SquirrelMail.
    **/

    global $color;
    $color[0]   = '#DCDCDC'; // (light gray)     TitleBar
    $color[1]   = '#800000'; // (red)
    $color[2]   = '#CC0000'; // (light red)      Warning/Error Messages
    $color[3]   = '#A0B8C8'; // (green-blue)     Left Bar Background
    $color[4]   = '#FFFFFF'; // (white)          Normal Background
    $color[5]   = '#FFFFCC'; // (light yellow)   Table Headers
    $color[6]   = '#000000'; // (black)          Text on left bar
    $color[7]   = '#0000CC'; // (blue)           Links
    $color[8]   = '#000000'; // (black)          Normal text
    $color[9]   = '#ABABAB'; // (mid-gray)       Darker version of #0
    $color[10]  = '#666666'; // (dark gray)      Darker version of #9
    $color[11]  = '#770000'; // (dark red)       Special Folders color
    $color[12]  = '#EDEDED'; // (light gray)     Alternate color for message list
    $color[13]  = '#800000'; // (dark red)       Color for quoted text -- > 1 quote
    $color[14]  = '#FF0000'; // (red)            Color for quoted text -- >> 2 or more
    $color[15]  = '#002266'; // (dark blue)      Unselectable folders
?>
